==> rendition-12.0.1.tgz: package/dist_esm5/components/Card/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import map from 'lodash/map';
import * as React from 'react';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import { DismissableContainer } from '../../internal/DismissableContainer';
import { Box } from '../Box';
import Divider from '../Divider';
import { Flex } from '../Flex';
import Heading from '../Heading';
var Wrapper = styled(DismissableContainer)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\t& {\n\t\tmin-height: ", ";\n\t\tpadding: ", ";\n\t}\n"], ["\n\t& {\n\t\tmin-height: ", ";\n\t\tpadding: ", ";\n\t}\n"])), function (props) { return props.minHeight || 'auto'; }, function (props) { return (props.small ? '24px' : '32px 44px'); });
var Card = function (_a) {
    var title = _a.title, cta = _a.cta, rows = _a.rows, children = _a.children, props = __rest(_a, ["title", "cta", "rows", "children"]);
    var hasHeader = title || cta;
    var Header = hasHeader && (React.createElement(React.Fragment, null,
        React.createElement(Flex, { justifyContent: "space-between", alignItems: "center" },
            React.createElement(Heading.h5, { fontSize: 2 }, title),
            cta),
        React.createElement(Divider, { my: 2 })));
    var Rows = rows &&
        map(rows, function (row, index) { return (React.createElement(Box, { key: index },
            index > 0 && React.createElement(Divider, null),
            row)); });
    var Body = children && React.createElement(Box, null, children);
    return (React.createElement(Wrapper, __assign({}, props),
        React.createElement(Box, { width: "100%" },
            Header,
            Rows,
            Body)));
};
export default asRendition(Card);
var templateObject_1;

==> rendition-14.9.0.tgz: package/dist_esm5/components/Card/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import map from 'lodash/map';
import * as React from 'react';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import { DismissableContainer } from '../../internal/DismissableContainer';
import { Box } from '../Box';
import Divider from '../Divider';
import { Flex } from '../Flex';
import Heading from '../Heading';
var Wrapper = styled(DismissableContainer)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\t& {\n\t\tpadding: ", ";\n\t}\n"], ["\n\t& {\n\t\tpadding: ", ";\n\t}\n"])), function (props) { return (props.small ? '24px' : '32px 44px'); });
var Card = function (_a) {
    var title = _a.title, cta = _a.cta, rows = _a.rows, children = _a.children, props = __rest(_a, ["title", "cta", "rows", "children"]);
    var hasHeader = title || cta;
    var Header = hasHeader && (React.createElement(React.Fragment, null,
        React.createElement(Flex, { justifyContent: "space-between", alignItems: "center" },
            React.createElement(Heading.h5, { fontSize: 2 }, title),
            cta),
        React.createElement(Divider, { my: 2 })));
    var Rows = rows &&
        map(rows, function (row, index) { return (React.createElement(Box, { key: index },
            index > 0 && React.createElement(Divider, null),
            row)); });
    var Body = children && React.createElement(Box, null, children);
    return (React.createElement(Wrapper, __assign({}, props),
        React.createElement(Box, { width: "100%" },
            Header,
            Rows,
            Body)));
};
export default asRendition(Card);
var templateObject_1;
